bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.broadcasting_multiplier
==============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.broadcasting_multiplier